@@ -1,5 +1,5 @@
 package Alien::SeqAlignment::edlib;
-$Alien::SeqAlignment::edlib::VERSION = '0.01';
+$Alien::SeqAlignment::edlib::VERSION = '0.02';
 use parent qw( Alien::Base );
 use Alien::Build::Plugin::Build::CMake; ## uses cmake build
 use Path::Tiny;
@@ -43,7 +43,7 @@ Alien::SeqAlignment::edlib
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -63,7 +63,8 @@ detect an existing install of parasail on your system.  If found it
 will use that.  If it cannot be found, the source code will be downloaded
 from the internet and it will be installed in a private share location
 for the use of other modules. The build provides the static and shared 
-libraries, but also the command line aligner (edlib-aligner). 
+libraries, but also the command line aligner (edlib-aligner, not currently
+available in Windows).
 
 =head1 NAME
 
@@ -98,9 +99,23 @@ alignment using the edit (Levenshtein) distance between two or more
 biological (usually) sequences. It can calculate the edit distance, 
 find the optimal aligment path and the coordinates (start/end) 
 locations. It supports multiple alignment modes such as global (NW), 
-prefix (SHW) and infix (HW)
+prefix (SHW) and infix (HW). The library does not handle utf8 and its
+primary use is to compute edit distances and alignments over small 
+(255 characters or fewer) alphabets as they occur in bioinformatic
+applications.
 
-Select the appropriate implementation for your needs.
+=item L<https://metacpan.org/pod/Text::Levenshtein::Edlib>
+An XS library that also wraps around the edlib library and returns
+edit distances, as well as alignment paths.
+
+=item L<https://metacpan.org/pod/Text::Levenshtein::XS>
+An XS library that computes edit distances but not alignment paths.
+This module was updated last in 2016 (see also its github repository
+at: https://github.com/ugexe/Text--Levenshtein--XS/)
+
+=item L<https://metacpan.org/pod/Text::LevenshteinXS>
+Yet another XS implementation of Levenshtein distance over strings 
+(no alignment path). This module was last updated in 2004. 
 
 =item L<Alien>
 
